Package: TrenchR
Title: Tools for Microclimate and Biophysical Ecology
Description: Tools for translating environmental change into organismal response. Microclimate models to vertically scale weather station data to organismal heights. The biophysical modeling tools include both general models for heat flows and specific models to predict body temperatures for a variety of ectothermic taxa. Additional functions model and temporally partition air and soil temperatures and solar radiation. Utility functions estimate the organismal and environmental parameters needed for biophysical ecology. 'TrenchR' focuses on relatively simple and modular functions so users can create transparent and flexible biophysical models. Many functions are derived from Gates (1980) <doi:10.1007/978-1-4612-6024-0> and Campbell and Norman (1988) <isbn:9780387949376>.
Version: 1.2.1
Maintainer: Lauren Buckley <lbuckley@uw.edu>
Authors@R: c(
    person("Lauren", "Buckley", role = c("aut", "cre"), email = "lbuckley@uw.edu", comment = c(ORCID = "0000-0003-1315-3818")),
    person("Bryan", "Briones Ortiz", role = c("aut")),
    person("Isaac", "Caruso", role = c("aut")),
    person("Aji", "John", role = c("aut"), comment = c(ORCID = "0000-0002-4401-1401")),
    person("Ofir", "Levy", role = c("aut"), comment = c(ORCID = "0000-0003-0920-1207")),
    person("Abigail", "Meyer", role = c("aut")),
    person("Eric", "Riddell", role = c("aut"), comment = c(ORCID = "0000-0002-4229-4911")),
    person("Yutaro", "Sakairi", role = c("aut")),
    person("Juniper", "Simonis", role = c("aut"), comment = c(ORCID = "0000-0001-9798-0460")),
    person("Brian", "Helmuth", role = c("ctb"), comment = c(ORCID = "0000-0003-0180-3414"))
  )
License: MIT + file LICENSE
Date: 2026-04-28
URL: https://trenchproject.github.io/TrenchR/,
        https://github.com/trenchproject/TrenchR
BugReports: https://github.com/trenchproject/TrenchR/issues
VignetteBuilder: knitr
Depends: R (>= 3.3.1)
Imports: deSolve, msm, Rdpack (>= 0.7), stats, zoo
Suggests: covr, knitr, rmarkdown, testthat
RdMacros: Rdpack
Encoding: UTF-8
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2026-04-29 01:59:18 UTC; lbuckley
Author: Lauren Buckley [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1315-3818>),
  Bryan Briones Ortiz [aut],
  Isaac Caruso [aut],
  Aji John [aut] (ORCID: <https://orcid.org/0000-0002-4401-1401>),
  Ofir Levy [aut] (ORCID: <https://orcid.org/0000-0003-0920-1207>),
  Abigail Meyer [aut],
  Eric Riddell [aut] (ORCID: <https://orcid.org/0000-0002-4229-4911>),
  Yutaro Sakairi [aut],
  Juniper Simonis [aut] (ORCID: <https://orcid.org/0000-0001-9798-0460>),
  Brian Helmuth [ctb] (ORCID: <https://orcid.org/0000-0003-0180-3414>)
Repository: CRAN
Date/Publication: 2026-04-29 02:30:02 UTC
Built: R 4.6.0; ; 2026-04-29 06:24:50 UTC; unix
