# Generated by roxygen2: do not edit by hand

export(DRYAIR)
export(Grashof_number)
export(Grashof_number_Gates)
export(Nusselt_from_Grashof)
export(Nusselt_from_Reynolds)
export(Nusselt_number)
export(Prandtl_number)
export(Qconduction_animal)
export(Qconduction_substrate)
export(Qconvection)
export(Qemitted_thermal_radiation)
export(Qevaporation)
export(Qmetabolism_from_mass)
export(Qmetabolism_from_mass_temp)
export(Qnet_Gates)
export(Qradiation_absorbed)
export(Qthermal_radiation_absorbed)
export(Reynolds_number)
export(TPC)
export(TPC_beta)
export(T_sky)
export(Tb_CampbellNorman)
export(Tb_Gates)
export(Tb_Gates2)
export(Tb_butterfly)
export(Tb_grasshopper)
export(Tb_limpet)
export(Tb_limpetBH)
export(Tb_lizard)
export(Tb_lizard_Fei)
export(Tb_mussel)
export(Tb_salamander_humid)
export(Tb_snail)
export(Tbed_mussel)
export(Tsoil)
export(VAPPRS)
export(WETAIR)
export(actual_vapor_pressure)
export(air_temp_profile)
export(air_temp_profile_neutral)
export(air_temp_profile_segment)
export(airpressure_from_elev)
export(azimuth_angle)
export(boundary_layer_resistance)
export(celsius_to_kelvin)
export(day_of_year)
export(daylength)
export(dec_angle)
export(degree_days)
export(degrees_to_radians)
export(direct_solar_radiation)
export(diurnal_radiation_variation)
export(diurnal_temp_variation_sine)
export(diurnal_temp_variation_sineexp)
export(diurnal_temp_variation_sinesqrt)
export(external_resistance_to_water_vapor_transfer)
export(fahrenheit_to_celsius)
export(fahrenheit_to_kelvin)
export(free_or_forced_convection)
export(heat_transfer_coefficient)
export(heat_transfer_coefficient_approximation)
export(heat_transfer_coefficient_simple)
export(kelvin_to_celsius)
export(latent_heat_vaporization_h2o)
export(mass_from_length)
export(monthly_solar_radiation)
export(partition_solar_radiation)
export(proportion_diffuse_solar_radiation)
export(proportion_silhouette_area)
export(proportion_silhouette_area_shapes)
export(radians_to_degrees)
export(saturation_vapor_pressure)
export(saturation_water_vapor_pressure)
export(soil_conductivity)
export(soil_specific_heat)
export(soil_temperature)
export(soil_temperature_equation)
export(soil_temperature_function)
export(soil_temperature_integrand)
export(solar_noon)
export(solar_radiation)
export(specific_heat_h2o)
export(stefan_boltzmann_constant)
export(surface_area_from_length)
export(surface_area_from_mass)
export(surface_area_from_volume)
export(surface_roughness)
export(volume_from_length)
export(von_karman_constant)
export(wind_speed_profile_neutral)
export(wind_speed_profile_segment)
export(zenith_angle)
importFrom(Rdpack,reprompt)
importFrom(deSolve,ode)
importFrom(msm,rtnorm)
importFrom(stats,integrate)
importFrom(stats,lm)
importFrom(stats,runif)
importFrom(stats,uniroot)
importFrom(zoo,na.approx)
