context("Single Sine")
test_that("degree day function-single-sine work", {
  #fpath <- test_path("degree-days-single-sine.csv")
#  singlesine <- read.csv(fpath)
 # singlesine$DD.Trench<-degree_days(singlesine$Air.min,singlesine$Air.max,12,33,"single.sine")
 # corrsingsine=cor(singlesine$Degree.days,singlesine$DD.Trench,method = "pearson")
 # expect_gte(corrsingsine, .94)
  #rm(singlesine)
  expect_equal(degree_days(T_min=7, T_max=14, LDT=12, UDT=33, method="single.sine"), .47)
})